DebitRequest class

Constructors

DebitRequest(String? memberId, String? giftCardNo, String orderId, int? numPpl, String? tixNo, String? tableNo, int serviceType, String staffName, int subtotalInCents, int taxInCents, int tipInCents, int discInCents, int serviceChargeInCents, int amtInCents, int bagFeeInCents, List<CashBackAppliedResponse> appliedCashbacks, Map<PayType, int>? paymentByTypes)
DebitRequest.fromJson(Map<String, dynamic> json)
factory

Properties

amtInCents int
final
appliedCashbacks List<CashBackAppliedResponse>
final
bagFeeInCents int
final
discInCents int
final
giftCardNo String?
final
hashCode int
The hash code for this object.
no setterinherited
memberId String?
final
numPpl int?
final
orderId String
final
paymentByTypes Map<PayType, int>?
possible keys: giftcard, cashback and nonCash
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serviceChargeInCents int
final
serviceType int
dine-in or pick up 0 = dine-in 10 = pick up 20 = delivery
final
staffName String
final
subtotalInCents int
final
tableNo String?
final
taxInCents int
final
tipInCents int
if this exists, it means tip is fixed
final
tixNo String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited