DebitResponse class

Constructors

DebitResponse(DebitStatus status, String? tranId, int? amtDebited, int? tip, int? remainingBalance, String? last4, String? reason, int? earnCashback, String? memberId)

Properties

amtDebited int?
final
earnCashback int?
final
hashCode int
The hash code for this object.
no setterinherited
last4 String?
final
memberId String?
final
reason String?
final
remainingBalance int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status DebitStatus
final
tip int?
final
tranId String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited