MemberDetail class

Constructors

MemberDetail(String? memberId, String firstName, String lastName, String? countryCode, String? phoneNumber, int cashback, num points)

Properties

cashback int
final
countryCode String?
final
firstName String
final
hashCode int
The hash code for this object.
no setterinherited
lastName String
final
memberId String?
final
phoneNumber String?
final
points num
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited