RefundResponse class

Constructors

RefundResponse(GeneralStatus status, String? tranId, int? refundAmt, int? refundCashbackAmt, String? reason, int? code)

Properties

code int?
final
hashCode int
The hash code for this object.
no setterinherited
reason String?
final
refundAmt int?
final
refundCashbackAmt int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status GeneralStatus
final
tranId String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited