ChargeAmtCallbackResult class
Constructors
-
ChargeAmtCallbackResult(GeneralStatus status, String partnerTranId, Map<
PayType, int> payTypeAmt)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- partnerTranId → String
-
final
-
payTypeAmt
→ Map<
PayType, int> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → GeneralStatus
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited