ReportResponse class
Constructors
- ReportResponse(int totalInStoreGiftCardSalesOrReload, int totalInStoreGiftCardSaleAndReloadCash, int totalInStoreGiftCardSaleAndReloadNonCash, int totalGiftcardCost, int totalSpentByGiftCard, int totalInStoreGiftCardSpentAmt, int totalScanPayTipAmt, int totalAppOrderPaidByGiftcard, int totalAppOrderPaidByGiftcardCost)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalAppOrderPaidByGiftcard → int
-
final
- totalAppOrderPaidByGiftcardCost → int
-
final
- totalGiftcardCost → int
-
final
- totalInStoreGiftCardSaleAndReloadCash → int
-
final
- totalInStoreGiftCardSaleAndReloadNonCash → int
-
final
- totalInStoreGiftCardSalesOrReload → int
-
final
- totalInStoreGiftCardSpentAmt → int
-
final
- totalScanPayTipAmt → int
-
final
- totalSpentByGiftCard → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited